@@ -16,7 +16,7 @@
 import json
 import os
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from os_collect_config import exc
 from os_collect_config.openstack.common import log
